[−][src]Module libtectonic::postprocessing
functions for histogram, event analytics
Modules
| candle | candle data structure |
| event | events stream from slice of updates |
| histogram | |
| level | orderbook data structure: [price -> time -> size] Level is the transpose of updates normally updates are of shape [time -> price -> size] this is [price -> time -> size] to keep track of size changes on each price level over time. |
| orderbook | orderbook data structure: [time -> price -> size] |