[−][src]Module libtectonic::postprocessing::level
orderbook data structure: [price -> time -> size] Level is the transpose of updates normally updates are of shape [time -> price -> size] this is [price -> time -> size] to keep track of size changes on each price level over time.
Structs
| Levels | data structure for storing levels |