Data structure for rebinning orderbooks
If you think of an order as a 2D image, rebinning is lowering the resolution
For example, the raw orderbook is 1 nano second apart, you can "zoom out" to 1 second
Price rebinning is similar.
a map from time to orderbook
convert a list of updates to rebinned orderbook with fixed number of time steps bins and ticks bins
Formats the value using the given formatter. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)