[−][src]Module libtectonic::storage::utils
Utility functions
Functions
| scan_files_for_range | search every matching dtf file under folder for timestamp range |
| total_folder_updates_len | Get total number of updates from all files in a folder |