[−][src]Module libtectonic::client
Rust tectonicdb client Rust implementation of tectonicdb client
Re-exports
pub use self::cxn::Cxn; |
pub use self::pool::CxnPool; |
pub use self::insert_command::InsertCommand; |
Modules
| circular_queue | ring buffer A circular buffer-like queue. |
| cxn | implementation for Cxn struct |
| insert_command | builder for insertion command, add or bulk add |
| pool | implementation for CxnPool struct |
Enums
| TectonicError | Client errors |
Functions
| get_cxn | Creates a new connection to TectonicDB, using configuration values from environment values or defaults to localhost:9001 if none are set. |
| get_cxn_pool | Creates a new connection pool to TectonicDB, using configuration values from environment values or defaults to localhost:9001 if none are set. |