pub struct Histogram {
pub boundaries: Vec<f64>,
// some fields omitted
}Create a histogram along some dimension, for example price
Basically, put a list of prices into bins
lower boundary of the bin
create a new histogram from a list of price and reject outliers
m is the threshold for z-score
convert value to lower boundary of the bin
get spatial temporal histograms from a list of update
returns price history and time histogram
m is value of z-score cutoff
get index of the bin based on boundary price which is the lower boundary of the bin
Formats the value using the given formatter. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static