[−][src]Struct libtectonic::postprocessing::orderbook::RebinnedOrderbook
Data structure for rebinning orderbooks
If you think of an order as a 2D image, rebinning is lowering the resolution For example, the raw orderbook is 1 nano second apart, you can "zoom out" to 1 second
Price rebinning is similar.
Fields
book: IndexMap<u64, Orderbook>a map from time to orderbook
price_hist: Histogramhistogram of price
Methods
impl RebinnedOrderbook[src]
impl RebinnedOrderbookpub fn from( | [src] |
convert a list of updates to rebinned orderbook with fixed number of time steps bins and ticks bins